@@ -34,6 +34,7 @@ func (f fakeLayer) MediaType() (types.MediaType, error) {
 func newFakeLayer(t *testing.T) v1.Layer {
 	layer, err := tarball.LayerFromFile("testdata/bundle.tar.gz")
 	require.NoError(t, err)
+	require.NotNil(t, layer)
 
 	return fakeLayer{layer}
 }
@@ -68,15 +69,15 @@ func TestClient_LoadBuiltinPolicies(t *testing.T) {
 			name:     "happy path",
 			cacheDir: "testdata/happy",
 			want: []string{
-				"testdata/happy/policy/content/kubernetes",
-				"testdata/happy/policy/content/docker",
+				filepath.Join("testdata/happy/policy/content/kubernetes"),
+				filepath.Join("testdata/happy/policy/content/docker"),
 			},
 		},
 		{
 			name:     "empty roots",
 			cacheDir: "testdata/empty",
 			want: []string{
-				"testdata/empty/policy/content",
+				filepath.Join("testdata/empty/policy/content"),
 			},
 		},
 		{
@@ -97,10 +98,24 @@ func TestClient_LoadBuiltinPolicies(t *testing.T) {
 			// Mock image
 			img := new(fakei.FakeImage)
 			img.LayersReturns([]v1.Layer{newFakeLayer(t)}, nil)
+			img.ManifestReturns(&v1.Manifest{
+				Layers: []v1.Descriptor{
+					{
+						MediaType: "application/vnd.cncf.openpolicyagent.layer.v1.tar+gzip",
+						Size:      100,
+						Digest: v1.Hash{
+							Algorithm: "sha256",
+							Hex:       "cba33656188782852f58993f45b68bfb8577f64cdcf02a604e3fc2afbeb5f2d8"},
+						Annotations: map[string]string{
+							"org.opencontainers.image.title": "bundle.tar.gz",
+						},
+					},
+				},
+			}, nil)
 
 			// Mock OCI artifact
 			mediaType := "application/vnd.cncf.openpolicyagent.layer.v1.tar+gzip"
-			art, err := oci.NewArtifact("repo", mediaType, true, oci.WithImage(img))
+			art, err := oci.NewArtifact("repo", mediaType, true, true, oci.WithImage(img))
 			require.NoError(t, err)
 
 			c, err := policy.NewClient(tt.cacheDir, true, policy.WithOCIArtifact(art))
@@ -202,6 +217,20 @@ func TestClient_NeedsUpdate(t *testing.T) {
 			img := new(fakei.FakeImage)
 			img.LayersReturns([]v1.Layer{newFakeLayer(t)}, nil)
 			img.DigestReturns(tt.digestReturns.h, tt.digestReturns.err)
+			img.ManifestReturns(&v1.Manifest{
+				Layers: []v1.Descriptor{
+					{
+						MediaType: "application/vnd.cncf.openpolicyagent.layer.v1.tar+gzip",
+						Size:      100,
+						Digest: v1.Hash{
+							Algorithm: "sha256",
+							Hex:       "cba33656188782852f58993f45b68bfb8577f64cdcf02a604e3fc2afbeb5f2d8"},
+						Annotations: map[string]string{
+							"org.opencontainers.image.title": "bundle.tar.gz",
+						},
+					},
+				},
+			}, nil)
 
 			// Create a policy directory
 			err := os.MkdirAll(filepath.Join(tmpDir, "policy"), os.ModePerm)
@@ -218,7 +247,7 @@ func TestClient_NeedsUpdate(t *testing.T) {
 			}
 
 			mediaType := "application/vnd.cncf.openpolicyagent.layer.v1.tar+gzip"
-			art, err := oci.NewArtifact("repo", mediaType, true, oci.WithImage(img))
+			art, err := oci.NewArtifact("repo", mediaType, true, true, oci.WithImage(img))
 			require.NoError(t, err)
 
 			c, err := policy.NewClient(tmpDir, true, policy.WithOCIArtifact(art), policy.WithClock(tt.clock))
@@ -299,10 +328,24 @@ func TestClient_DownloadBuiltinPolicies(t *testing.T) {
 			img := new(fakei.FakeImage)
 			img.DigestReturns(tt.digestReturns.h, tt.digestReturns.err)
 			img.LayersReturns(tt.layersReturns.layers, tt.layersReturns.err)
+			img.ManifestReturns(&v1.Manifest{
+				Layers: []v1.Descriptor{
+					{
+						MediaType: "application/vnd.cncf.openpolicyagent.layer.v1.tar+gzip",
+						Size:      100,
+						Digest: v1.Hash{
+							Algorithm: "sha256",
+							Hex:       "cba33656188782852f58993f45b68bfb8577f64cdcf02a604e3fc2afbeb5f2d8"},
+						Annotations: map[string]string{
+							"org.opencontainers.image.title": "bundle.tar.gz",
+						},
+					},
+				},
+			}, nil)
 
 			// Mock OCI artifact
 			mediaType := "application/vnd.cncf.openpolicyagent.layer.v1.tar+gzip"
-			art, err := oci.NewArtifact("repo", mediaType, true, oci.WithImage(img))
+			art, err := oci.NewArtifact("repo", mediaType, true, true, oci.WithImage(img))
 			require.NoError(t, err)
 
 			c, err := policy.NewClient(tempDir, true, policy.WithClock(tt.clock), policy.WithOCIArtifact(art))
